@@ -1,7 +1,7 @@
 package Test::SQL::Schema::Versioned;
 
 our $DATE = '2015-04-22'; # DATE
-our $VERSION = '0.15'; # VERSION
+our $VERSION = '0.16'; # VERSION
 
 use 5.010001;
 use strict;
@@ -21,6 +21,7 @@ sub sql_schema_spec_ok {
     my ($spec, $twdb) = @_;
 
     subtest "sql schema spec test" => sub {
+        # some sanity checks
         is(ref($spec), 'HASH', 'spec is a hash') or return;
         ok($spec->{latest_v} >= 1, 'latest_v >= 1') or return;
         ok($spec->{install}, 'has install') or return;
@@ -30,7 +31,10 @@ sub sql_schema_spec_ok {
 
         subtest "testing schema creation using install" => sub {
             my $dbh = $twdb->create_db;
-            lives_ok { create_or_update_db_schema(dbh=>$dbh, spec=>$spec) };
+            lives_ok {
+                my $res = create_or_update_db_schema(dbh=>$dbh, spec=>$spec);
+                is($res->[0], 200, 'create/update status') or diag explain $res;
+            };
         };
 
         subtest "testing schema upgrade from v1" => sub {
@@ -38,9 +42,14 @@ sub sql_schema_spec_ok {
             lives_ok {
                 local $spec->{install} = $spec->{install_v1};
                 local $spec->{latest_v} = 1;
-                create_or_update_db_schema(dbh=>$dbh, spec=>$spec);
+                my $res = create_or_update_db_schema(dbh=>$dbh, spec=>$spec);
+                is($res->[0], 200, 'create/update status') or diag explain $res;
             } "create with install_v1";
-            lives_ok { create_or_update_db_schema(dbh=>$dbh, spec=>$spec) };
+
+            lives_ok {
+                my $res = create_or_update_db_schema(dbh=>$dbh, spec=>$spec);
+                is($res->[0], 200, 'create/update status') or diag explain $res;
+            };
         } if $spec->{latest_v} > 1;
     };
 }
@@ -60,7 +69,7 @@ Test::SQL::Schema::Versioned - Test SQL::Schema::Versioned spec
 
 =head1 VERSION
 
-This document describes version 0.15 of Test::SQL::Schema::Versioned (from Perl distribution SQL-Schema-Versioned), released on 2015-04-22.
+This document describes version 0.16 of Test::SQL::Schema::Versioned (from Perl distribution SQL-Schema-Versioned), released on 2015-04-22.
 
 =head1 FUNCTIONS
 
